@@ -5,7 +5,7 @@
 ##############################################################
 
 # Author: Christos Zamantzas <christos.zamantzas@gmail.com>
-# Version: 0.4.4-12
+# Version: 0.4.4-14
 
 import os
 import sys
@@ -239,6 +239,8 @@ class MyForm(QtGui.QMainWindow):
                 QtCore.QObject.connect(self.ui.btnCreateConfigSSH, QtCore.SIGNAL('clicked()'), self.doCreateConfigSSH)
                 QtCore.QObject.connect(self.ui.btnCreateConfigCommands1, QtCore.SIGNAL('clicked()'), self.doCreateConfigCommands1)
                 QtCore.QObject.connect(self.ui.btnCreateConfigCommands2, QtCore.SIGNAL('clicked()'), self.doCreateConfigCommands2)
+                QtCore.QObject.connect(self.ui.btnPrefix1, QtCore.SIGNAL('clicked()'), self.doPrefix1)
+                QtCore.QObject.connect(self.ui.btnPrefix2, QtCore.SIGNAL('clicked()'), self.doPrefix2)
                   # Initialise
                 QtCore.QObject.connect(self.ui.btnInit, QtCore.SIGNAL('clicked()'), self.doInit)
                 QtCore.QObject.connect(self.ui.btnReset, QtCore.SIGNAL('clicked()'), self.doReset)
@@ -420,7 +422,40 @@ class MyForm(QtGui.QMainWindow):
             showMessage(message)
             doUpdateConfig()
             
-        #TAB: Commands Renaming       
+        #TAB: Commands Renaming
+        def doPrefix1(self):
+             prefix = self.ui.linePrefix1.text()
+             self.ui.lineCheck.setText(    "%s" % prefix + COM_CHECK)
+             #self.ui.lineReboot.setText(   "%s" % prefix + COM_REBOOT)
+             #self.ui.linePowerOff.setText( "%s" % prefix + COM_POWEROFF)
+             #self.ui.linePower.setText(    "%s" % prefix + COM_POWER)
+             self.ui.lineLocation.setText( "%s" % prefix + COM_LOCATION)
+             #self.ui.lineRemoteOn.setText( "%s" % prefix + COM_REMOTEON)
+             #self.ui.lineRemoteOff.setText("%s" % prefix + COM_REMOTEOFF)
+             self.ui.lineCamera.setText(   "%s" % prefix + COM_CAMERA)
+             self.ui.lineCall.setText(     "%s" % prefix + COM_CALL)
+             self.ui.lineLock.setText(     "%s" % prefix + COM_LOCK)
+             self.ui.lineUnlock.setText(   "%s" % prefix + COM_UNLOCK)
+             self.ui.lineTrackOn.setText(  "%s" % prefix + COM_TRACKON)
+             self.ui.lineTrackOff.setText( "%s" % prefix + COM_TRACKOFF)
+
+        def doPrefix2(self):
+             prefix = self.ui.linePrefix2.text()
+             #self.ui.lineCheck.setText(    "%s" % prefix + COM_CHECK)
+             self.ui.lineReboot.setText(   "%s" % prefix + COM_REBOOT)
+             self.ui.linePowerOff.setText( "%s" % prefix + COM_POWEROFF)
+             self.ui.linePower.setText(    "%s" % prefix + COM_POWER)
+             #self.ui.lineLocation.setText( "%s" % prefix + COM_LOCATION)
+             self.ui.lineRemoteOn.setText( "%s" % prefix + COM_REMOTEON)
+             self.ui.lineRemoteOff.setText("%s" % prefix + COM_REMOTEOFF)
+             #self.ui.lineCamera.setText(   "%s" % prefix + COM_CAMERA)
+             #self.ui.lineCall.setText(     "%s" % prefix + COM_CALL)
+             #self.ui.lineLock.setText(     "%s" % prefix + COM_LOCK)
+             #self.ui.lineUnlock.setText(   "%s" % prefix + COM_UNLOCK)
+             #self.ui.lineTrackOn.setText(  "%s" % prefix + COM_TRACKON)
+             #self.ui.lineTrackOff.setText( "%s" % prefix + COM_TRACKOFF)
+             
+             
         def doCreateConfigCommands1(self):
 
             Check    = self.ui.lineCheck.text()
